from setuptools import setup

setup(
    name='shauntal_tracker',
    version='1.0.1',  # Your unique version number
    description='Track your consistency on a line graph',
    author='Jamangi',
    author_email='jamangi.jmg@gmail.com',
    packages=['shauntal_tracker'],
    install_requires=['matplotlib'],
)
